# Repository for Machine Learning in Geotechnics

<div style="text-align:center;">
    <img src="https://img.shields.io/badge/Python-3.7%2B-brightgreen" alt="Python version">
    <a href="https://pypi.org/project/mlgeo" target="_blank">
        <img src="https://img.shields.io/pypi/v/mlgeo?style=flat&color=brightgreen&label=PyPI%20Package" alt="Package version">
    </a>
    <br><br>
</div>


This is the beginning of an exciting effort in lowering the barrier of entry to 
Machine Learning for Geoprofessionals by:

1. Distributing relevant and interesting toy datasets to practice with (now)
2. Offering tools that can make applying ML easier, especially for beginners (soon)


### TRB2021 AKG70 Presentation

Click on the image below to review the presentation introducing MLgeo given by 
[Nick Machairas](https://groundwork.ai/nickmachairas) during the committee 
meeting of AKG70 at TRB Annual Meeting 2021.

<a href="https://docs.google.com/presentation/d/e/2PACX-1vSY3gSpaS7dOQrtrwouNKZKm000_uMI1CmtuR94HZ9tR_54U7C3IGHaRDbe9QE2V6xUCBPYMx2iD7Xc/pub?start=false&loop=false&delayms=3000">
    <img src="https://storage.googleapis.com/mlgeo/TRB2021_Presentation_Cover_MLgeo.jpg" alt="TRB Presentation">
</a>


---

<div>
    <h3><img src="https://mirrors.creativecommons.org/presskit/buttons/88x31/png/by-sa.png" alt="CC-BY-SA-4.0" height="30px"><br>License: Attribution-ShareAlike 4.0 International (CC BY-SA 4.0)
    </h3>
    <p>
        You are free to <strong>Share</strong> (copy and redistribute the material 
        in any medium or format) and <strong>Adapt</strong> (remix, transform, and 
        build upon the material for any purpose, even commercially), under the 
        following terms: <strong>Attribution</strong> — You must give appropriate 
        credit, provide a link to the license, and indicate if changes were made. 
        You may do so in any reasonable manner, but not in any way that suggests 
        the licensor endorses you or your use. <strong>ShareAlike</strong> — If 
        you remix, transform, or build upon the material, you must distribute 
        your contributions under the same license as the original. More details 
        <a href="https://creativecommons.org/licenses/by-sa/4.0/">here</a>.
    </p>
</div>
